## Alice ChangeLog

Here you can see the full list of changes between each Alice release.

##### Version 1.0.4
First public release
- PyPi support for anyone to install easily


##### Version 1.0.0, 1.0.1, 1.0.2, 1.0.3
On the fly checks like:

- tech_review
- product_review
- close_dangerous_pr
- comment_guidelines
- notify_lead_on_given_action
- notify_channel_on_merge
- notify_on_sensitive_files_touched
- remind_direct_release_guideline_on_merge



